package com.xy.utils;

import cn.dev33.satoken.stp.StpUtil;
import com.xy.config.SaTokenAuthorizeConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * satoken工具类
 */
@Component
@ConditionalOnMissingClass("com.xy.filter.SaTokenConfigure")
public class SaTokenUtils {

    private static SaTokenAuthorizeConfig saTokenAuthorizeConfig;

    @Autowired(required = false)
    private void setSaTokenAuthorizeConfig(SaTokenAuthorizeConfig saTokenAuthorizeConfig) {
        SaTokenUtils.saTokenAuthorizeConfig = saTokenAuthorizeConfig;
    }

    /**
     * 获取token
     *
     * @return
     */
    public static String getToken() {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes()).getRequest();
        return request.getHeader(saTokenAuthorizeConfig.getTokenName());
    }

    /**
     * 获取登录id
     *
     * @return
     */
    public static Object getId() {
        return StpUtil.getLoginIdByToken(getToken());
    }

    /**
     * 获取登录id
     *
     * @return
     */
    public static <T> T getId(Class<T> tClass) {
        Object id = getId();
        String idStr = id.toString();
        return tClass.equals(Long.class) ? (T) Long.valueOf(idStr)
                : tClass.equals(Integer.class) ? (T) Integer.valueOf(idStr)
                : tClass.equals(String.class) ? (T) idStr
                : (T) id;
    }

    /**
     * 获取菜单权限列表
     *
     * @return
     */
    public static List<String> getPermissions() {
        return StpUtil.getPermissionList(getId());
    }

    /**
     * 获取角色权限列表
     *
     * @return
     */
    public static List<String> getRoles() {
        return StpUtil.getRoleList(getId());
    }
}
